@@ -1,20 +1,25 @@
 //! Helpers for unit tests
 
 use crate::conn::DbSyncLevel;
-use crate::db::DbKind;
+use crate::db::DbKindAuthored;
+use crate::db::DbKindConductor;
+use crate::db::DbKindP2pAgentStore;
+use crate::db::DbKindP2pMetrics;
+use crate::db::DbKindT;
+use crate::db::DbKindWasm;
 use crate::db::DbWrite;
-use holochain_zome_types::test_utils::fake_cell_id;
+use holochain_zome_types::fake_dna_hash;
 use shrinkwraprs::Shrinkwrap;
 use std::sync::Arc;
 use tempdir::TempDir;
 
-/// Create a [TestDb] of [DbKind::Cell], backed by a temp directory.
-pub fn test_cell_db() -> TestDb {
-    let cell_id = fake_cell_id(1);
-    test_db(DbKind::Cell(cell_id))
+/// Create a [TestDb] of [`DbKindAuthored`], backed by a temp directory.
+pub fn test_authored_db() -> TestDb<DbKindAuthored> {
+    let dna_hash = fake_dna_hash(1);
+    test_db(DbKindAuthored(Arc::new(dna_hash)))
 }
 
-fn test_db(kind: DbKind) -> TestDb {
+fn test_db<Kind: DbKindT + Send + Sync + 'static>(kind: Kind) -> TestDb<Kind> {
     let tmpdir = TempDir::new("holochain-test-environments").unwrap();
     TestDb {
         db: DbWrite::new(tmpdir.path(), kind, crate::conn::DbSyncLevel::default())
@@ -31,17 +36,17 @@ pub fn test_dbs() -> TestDbs {
 
 /// A test database in a temp directory
 #[derive(Shrinkwrap)]
-pub struct TestDb {
+pub struct TestDb<Kind: DbKindT> {
     #[shrinkwrap(main_field)]
     /// sqlite database
-    db: DbWrite,
+    db: DbWrite<Kind>,
     /// temp directory for this environment
     tmpdir: TempDir,
 }
 
-impl TestDb {
+impl<Kind: DbKindT> TestDb<Kind> {
     /// Accessor
-    pub fn db(&self) -> DbWrite {
+    pub fn db(&self) -> DbWrite<Kind> {
         self.db.clone()
     }
 
@@ -54,13 +59,13 @@ impl TestDb {
 /// A container for all three non-cell environments
 pub struct TestDbs {
     /// A test conductor environment
-    conductor: DbWrite,
+    conductor: DbWrite<DbKindConductor>,
     /// A test wasm environment
-    wasm: DbWrite,
+    wasm: DbWrite<DbKindWasm>,
     /// A test p2p state environment
-    p2p_agent_store: DbWrite,
+    p2p_agent_store: DbWrite<DbKindP2pAgentStore>,
     /// A test p2p metrics environment
-    p2p_metrics: DbWrite,
+    p2p_metrics: DbWrite<DbKindP2pMetrics>,
     /// The shared root temp dir for these environments
     tempdir: TempDir,
 }
@@ -69,18 +74,22 @@ pub struct TestDbs {
 impl TestDbs {
     /// Create all three non-cell environments at once
     pub fn new(tempdir: TempDir) -> Self {
-        use DbKind::*;
-        let conductor = DbWrite::new(tempdir.path(), Conductor, DbSyncLevel::default()).unwrap();
-        let wasm = DbWrite::new(tempdir.path(), Wasm, DbSyncLevel::default()).unwrap();
+        let conductor =
+            DbWrite::new(tempdir.path(), DbKindConductor, DbSyncLevel::default()).unwrap();
+        let wasm = DbWrite::new(tempdir.path(), DbKindWasm, DbSyncLevel::default()).unwrap();
         let space = Arc::new(kitsune_p2p::KitsuneSpace(vec![0; 36]));
         let p2p_agent_store = DbWrite::new(
             tempdir.path(),
-            P2pAgentStore(space.clone()),
+            DbKindP2pAgentStore(space.clone()),
+            DbSyncLevel::default(),
+        )
+        .unwrap();
+        let p2p_metrics = DbWrite::new(
+            tempdir.path(),
+            DbKindP2pMetrics(space),
             DbSyncLevel::default(),
         )
         .unwrap();
-        let p2p_metrics =
-            DbWrite::new(tempdir.path(), P2pMetrics(space), DbSyncLevel::default()).unwrap();
         Self {
             conductor,
             wasm,
@@ -90,19 +99,19 @@ impl TestDbs {
         }
     }
 
-    pub fn conductor(&self) -> DbWrite {
+    pub fn conductor(&self) -> DbWrite<DbKindConductor> {
         self.conductor.clone()
     }
 
-    pub fn wasm(&self) -> DbWrite {
+    pub fn wasm(&self) -> DbWrite<DbKindWasm> {
         self.wasm.clone()
     }
 
-    pub fn p2p_agent_store(&self) -> DbWrite {
+    pub fn p2p_agent_store(&self) -> DbWrite<DbKindP2pAgentStore> {
         self.p2p_agent_store.clone()
     }
 
-    pub fn p2p_metrics(&self) -> DbWrite {
+    pub fn p2p_metrics(&self) -> DbWrite<DbKindP2pMetrics> {
         self.p2p_metrics.clone()
     }
 
